==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/foundation/gui/render/SandPaperRenderer.java <==
package com.zurrtum.create.client.foundation.gui.render;

import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.infrastructure.component.SandPaperItemComponent;
import net.minecraft.class_10444;
import net.minecraft.class_11239;
import net.minecraft.class_11684;
import net.minecraft.class_1799;
import net.minecraft.class_308;
import net.minecraft.class_310;
import net.minecraft.class_3902;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_765;
import net.minecraft.class_811;

public class SandPaperRenderer extends class_11239<SandPaperRenderState> {
    private final class_10444 renderState = new class_10444();
    private final class_1799 stack;

    public SandPaperRenderer(class_4597.class_4598 vertexConsumers) {
        super(vertexConsumers);
        stack = AllItems.SAND_PAPER.method_7854();
        stack.method_57379(AllDataComponents.SAND_PAPER_JEI, class_3902.field_17274);
    }

    @Override
    protected void render(SandPaperRenderState state, class_4587 matrices) {
        matrices.method_46416(0, -0.35f, 0);
        matrices.method_22905(1, -1, -1);
        class_310 mc = class_310.method_1551();
        class_308 lighting = mc.field_1773.method_71114();
        lighting.method_71034(class_308.class_11274.field_60026);
        stack.method_57379(AllDataComponents.SAND_PAPER_POLISHING, new SandPaperItemComponent(state.stack()));
        class_11684 renderDispatcher = mc.field_1773.method_72911();
        mc.method_65386().method_65598(renderState, stack, class_811.field_4317, null, null, 0);
        renderState.method_65604(matrices, renderDispatcher.method_73003(), class_765.field_32767, class_4608.field_21444, 0);
        renderDispatcher.method_73002();
    }

    @Override
    protected String method_70906() {
        return "Sand Paper";
    }

    @Override
    public Class<SandPaperRenderState> method_70903() {
        return SandPaperRenderState.class;
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/foundation/gui/render/SandPaperRenderer.java <==
package com.zurrtum.create.client.foundation.gui.render;

import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.AllItems;
import com.zurrtum.create.infrastructure.component.SandPaperItemComponent;
import net.minecraft.class_10444;
import net.minecraft.class_11239;
import net.minecraft.class_11684;
import net.minecraft.class_1799;
import net.minecraft.class_308;
import net.minecraft.class_310;
import net.minecraft.class_3902;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_765;
import net.minecraft.class_811;

public class SandPaperRenderer extends class_11239<SandPaperRenderState> {
    private final class_10444 renderState = new class_10444();
    private final class_1799 stack;

    public SandPaperRenderer(class_4597.class_4598 vertexConsumers) {
        super(vertexConsumers);
        stack = AllItems.SAND_PAPER.method_7854();
        stack.method_57379(AllDataComponents.SAND_PAPER_JEI, class_3902.field_17274);
    }

    @Override
    protected void renderToTexture(SandPaperRenderState state, class_4587 matrices) {
        matrices.method_46416(0, -0.35f, 0);
        matrices.method_22905(1, -1, -1);
        class_310 mc = class_310.method_1551();
        class_308 lighting = mc.field_1773.method_71114();
        lighting.method_71034(class_308.class_11274.field_60026);
        stack.method_57379(AllDataComponents.SAND_PAPER_POLISHING, new SandPaperItemComponent(state.stack()));
        class_11684 renderDispatcher = mc.field_1773.method_72911();
        mc.method_65386().method_65598(renderState, stack, class_811.field_4317, null, null, 0);
        renderState.method_65604(matrices, renderDispatcher.method_73003(), class_765.field_32767, class_4608.field_21444, 0);
        renderDispatcher.method_73002();
    }

    @Override
    protected String method_70906() {
        return "Sand Paper";
    }

    @Override
    public Class<SandPaperRenderState> method_70903() {
        return SandPaperRenderState.class;
    }
}
